==> remap_0.2.1.tar.gz: remap/R/data.R <==
#' Snowpack at weather stations in Utah on April 1st, 2011.
#'
#' Water equivalent of snow density (WESD) in mm of water at various
#' location within and surrounding the state of Utah. WESD are
#' measured at weather stations within the Daily Global Historical
#' Climatology Network. April first measurements are used to
#' estimate snowpack for the state of Utah.
#'
#' @format An sf points object with 394 rows and 9 variables:
#' \describe{
#'   \item{ID}{Weather station identification code.}
#'   \item{STATION_NAME}{Weather station name.}
#'   \item{LATITUDE}{Latitude of weather station.}
#'   \item{LONGITUDE}{Longitude of weather station.}
#'   \item{ELEVATION}{Elevation of weather station.}
#'   \item{HUC2}{Largest watershed region containing this weather station
#'   (see \code{\link{utws}} data).}
#'   \item{WESD}{Water equivalent of snow density in mm of water.}
#'   \item{geometry}{sfc points in geographic coordinates.}
#' }
#' @source \url{ftp://ftp.ncdc.noaa.gov/pub/data/ghcn/daily}
"utsnow"



#' Watershed polygons within the state of Utah.
#'
#' Watersheds are defined by the United States Geological Survey.
#' Only the largest defines watersheds are used.
#'
#' @format An sf object with 394 rows and 2 variables:
#' \describe{
#'   \item{HUC2}{Largest watershed ID's defined by the USGS.}
#'   \item{geometry}{sfc multipolygon object in geographic coordinates.}
#' }
#' @source \url{https://www.usgs.gov/core-science-systems/ngp/national-hydrography/watershed-boundary-dataset?qt-science_support_page_related_con=4#qt-science_support_page_related_con}
"utws"

==> remap_0.3.2.tar.gz: remap/R/data.R <==
#' Snowpack at weather stations in Utah on April 1st, 2011.
#'
#' Water equivalent of snow density (WESD) in mm of water at various
#' location within and surrounding the state of Utah. WESD are
#' measured at weather stations within the Daily Global Historical
#' Climatology Network. April first measurements are used to
#' estimate snowpack for the state of Utah.
#' @name utsnow
#' @docType data
#' @format An sf points object with 394 rows and 8 variables:
#' \describe{
#'   \item{ID}{Weather station identification code.}
#'   \item{STATION_NAME}{Weather station name.}
#'   \item{LATITUDE}{Latitude of weather station.}
#'   \item{LONGITUDE}{Longitude of weather station.}
#'   \item{ELEVATION}{Elevation of weather station.}
#'   \item{HUC2}{Largest watershed region containing this weather station
#'   (see \code{\link{utws}} data).}
#'   \item{WESD}{Water equivalent of snow density in mm of water.}
#'   \item{geometry}{sfc points in geographic coordinates.}
#' }
#' @source \url{https://www1.ncdc.noaa.gov/pub/data/ghcn/daily/}
#' @examples
#' \donttest{
#' # If you run into issues with loading this dataset try running:
#' utsnow <- sf::st_read(system.file("extdata/utsnow.shp", package="remap"))
#' names(utsnow) <- c(
#'   "ID", "STATION_NAME", "LATITUDE", "LONGITUDE", "ELEVATION", "HUC2",
#'   "WESD", "geometry"
#' )
#' }
"utsnow"



#' Watershed polygons within the state of Utah.
#'
#' Watersheds are defined by the United States Geological Survey.
#' Only the largest defines watersheds are used.
#'
#' @name utws
#' @docType data
#' @format An sf object with 4 rows and 2 variables:
#' \describe{
#'   \item{HUC2}{Largest watershed ID's defined by the USGS.}
#'   \item{geometry}{sfc multipolygon object in geographic coordinates.}
#' }
#' @source \url{https://www.usgs.gov/national-hydrography/watershed-boundary-dataset}
#' @examples
#' \donttest{
#' # If you run into issues with loading this dataset try running:
#' utws <- sf::st_read(system.file("extdata/utws.shp", package="remap"))
#' }
"utws"
